LiveActivityStateUpdate class

Emitted on the FlutterLiveActivities.activityStateStream when state changes.

Constructors

LiveActivityStateUpdate({required String activityId, required LiveActivityState state})
const

Properties

activityId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LiveActivityState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited