MethodChannelFlutterLiveActivities class
- Inheritance
-
- Object
- PlatformInterface
- FlutterLiveActivitiesPlatform
- MethodChannelFlutterLiveActivities
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
areActivitiesEnabled(
) → Future< bool> -
override
-
endActivity(
String activityId) → Future< void> -
override
-
endAllActivities(
) → Future< void> -
override
-
getAllActivities(
) → Future< List< String> > -
override
-
isActivityRunning(
String activityId) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startActivity(
{required String title, required Map< String, dynamic> data, String? appGroup}) → Future<String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateActivity(
{required String activityId, required Map< String, dynamic> data}) → Future<void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited