FlutterLiveActivitiesPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterLiveActivitiesPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
areActivitiesEnabled(
) → Future< bool> -
endActivity(
String activityId) → Future< void> -
endAllActivities(
) → Future< void> -
getAllActivities(
) → Future< List< String> > -
isActivityRunning(
String activityId) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startActivity(
{required String title, required Map< String, dynamic> data, String? appGroup}) → Future<String> -
toString(
) → String -
A string representation of this object.
inherited
-
updateActivity(
{required String activityId, required Map< String, dynamic> data}) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterLiveActivitiesPlatform
-
getter/setter pair